<?php
session_start();
define('OFFLINE_THRESHOLD_SECONDS', 60);

// --- Verificaciones Iniciales y Obtención de Datos ---
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}
$user_id = $_SESSION['user_id'];
$current_user_name = $_SESSION['name'] ?? 'Usuario';
$current_user_phone = $_SESSION['phone'] ?? '';
if (!isset($_GET['id']) || !is_numeric($_GET['id']) || intval($_GET['id']) <= 0) {
    error_log("Invalid chat ID requested by user: " . $user_id);
    header('Location: dashboard.php?error=invalid_chat_id');
    exit();
}
$other_user_id = intval($_GET['id']);
if ($user_id === $other_user_id) {
    header('Location: dashboard.php?error=self_chat');
    exit();
}

require_once 'config.php';

// --- Obtener Información del Otro Usuario y su Estado ---
$other_user_status = 'offline';
$other_user_last_activity = null;
$other_user_name = 'Desconocido';
$other_user_phone = '';
$user_query = "SELECT u.id, u.name, u.phone, us.status, us.last_activity FROM users u LEFT JOIN user_status us ON u.id = us.user_id WHERE u.id = ?";
$user_stmt = $conn->prepare($user_query);
if ($user_stmt) {
    $user_stmt->bind_param("i", $other_user_id);
    $user_stmt->execute();
    $user_result = $user_stmt->get_result();
    if ($user_result->num_rows > 0) {
        $other_user = $user_result->fetch_assoc();
        $other_user_name = $other_user['name'];
        $other_user_phone = $other_user['phone'];
        $db_status = $other_user['status'];
        $other_user_last_activity = $other_user['last_activity'];
        if ($db_status === 'online' && $other_user_last_activity) {
            $last_activity_timestamp = strtotime($other_user_last_activity);
            if ((time() - $last_activity_timestamp) <= OFFLINE_THRESHOLD_SECONDS) {
                $other_user_status = 'online';
            } else {
                $other_user_status = 'offline';
            }
        } else {
            $other_user_status = 'offline';
        }
    } else {
        $user_stmt->close();
        $conn->close();
        error_log("Chat user ID (id={$other_user_id}) not found for user: {$user_id}.");
        header('Location: dashboard.php?error=chat_user_not_found');
        exit();
    }
    $user_stmt->close();
} else {
    error_log("Error preparing user info statement: " . $conn->error);
    $conn->close();
    header('Location: dashboard.php?error=db_error');
    exit();
}

// --- Obtener Historial de Mensajes ---
$messages_query = "SELECT id, sender_id, receiver_id, message, type, file_url, file_name, file_size, file_type, timestamp, `read`, delivered FROM messages WHERE ((sender_id = ? AND receiver_id = ?) OR (sender_id = ? AND receiver_id = ?)) AND deleted = 0 ORDER BY timestamp ASC";
$messages = [];
$messages_stmt = $conn->prepare($messages_query);
if ($messages_stmt) {
    $messages_stmt->bind_param("iiii", $user_id, $other_user_id, $other_user_id, $user_id);
    $messages_stmt->execute();
    $messages_result = $messages_stmt->get_result();
    while ($row = $messages_result->fetch_assoc()) {
        // Formatear timestamp a ISO 8601 UTC para JavaScript
        if ($row['timestamp']) {
            try {
                $date = new DateTime($row['timestamp'], new DateTimeZone('UTC')); // Asumiendo UTC
                $row['timestamp_iso'] = $date->format('c'); // Formato ISO 8601
            } catch (Exception $e) {
                error_log("Invalid timestamp DB ID {$row['id']}: {$row['timestamp']}. Error: " . $e->getMessage());
                $row['timestamp_iso'] = null;
            }
        } else {
            $row['timestamp_iso'] = null;
        }
        $messages[] = $row;
    }
    $messages_stmt->close();
} else {
    error_log("Error preparing messages history: " . $conn->error);
}

// --- Marcar Mensajes como Leídos ---
$update_read_on_load_query = "UPDATE messages SET `read` = 1 WHERE sender_id = ? AND receiver_id = ? AND `read` = 0";
$update_stmt = $conn->prepare($update_read_on_load_query);
if ($update_stmt) {
    $update_stmt->bind_param("ii", $other_user_id, $user_id);
    $update_stmt->execute();
    $update_stmt->close();
} else {
    error_log("Error preparing update read on load: " . $conn->error);
}

// --- Actualizar Estado Propio ---
$update_my_status_query = "INSERT INTO user_status (user_id, status, last_activity) VALUES (?, 'online', NOW()) ON DUPLICATE KEY UPDATE status = 'online', last_activity = NOW()";
$update_my_stmt = $conn->prepare($update_my_status_query);
if ($update_my_stmt) {
    $update_my_stmt->bind_param("i", $user_id);
    $update_my_stmt->execute();
    $update_my_stmt->close();
} else {
    error_log("Error preparing update own status: " . $conn->error);
}

$conn->close();
?>
<!DOCTYPE html>
<html lang="es" class="h-full">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no">
    <title>FlyChat - Chat con <?php echo htmlspecialchars($other_user_name); ?></title>

    <!-- Dependencias CSS -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/emoji-mart@latest/css/emoji-mart.css">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/photoswipe/5.4.4/photoswipe.min.css" />

    <!-- CSS Personalizado -->
    <link rel="stylesheet" href="css/style.css">

    <style>
        /* Estilos Base y Overrides */
        * { -webkit-tap-highlight-color: transparent; outline: none; }
        #chat-messages { scroll-behavior: smooth; }
        .message-status-icon { font-size: 0.75rem; opacity: 0.8; }
        #emoji-picker-container { position: absolute; bottom: calc(100% + 8px); left: 8px; z-index: 50; display: none; background-color: white; border-radius: 8px; box-shadow: 0 4px 12px rgba(0,0,0,0.15); }
        .typing-indicator span { display: inline-block; width: 6px; height: 6px; margin: 0 1px; background-color: #9ca3af; border-radius: 50%; animation: typing 1s infinite ease-in-out; }
        .typing-indicator span:nth-child(2) { animation-delay: 0.2s; }
        .typing-indicator span:nth-child(3) { animation-delay: 0.4s; }
        @keyframes typing { 0%, 100% { opacity: 0.3; transform: scale(0.8); } 50% { opacity: 1; transform: scale(1); } }
        @keyframes spin { 0% { transform: rotate(0deg); } 100% { transform: rotate(360deg); } }
        .spinner-tiny { border: 2px solid rgba(255,255,255,0.3); border-top-color: white; border-radius: 50%; width: 12px; height: 12px; animation: spin 1s linear infinite; }
        .status-dot { display: inline-block; }
        .pswp__bg { background: rgba(0, 0, 0, 0.9) !important; }
        .pswp--one-image .pswp__counter { display: none !important; }
        .pswp__button { background-color: rgba(0, 0, 0, 0.5) !important; }
        .blue-gradient { background: linear-gradient(to right, #3b82f6, #2563eb); }

        /* Padding inferior para mensajes */
        #chat-messages {
             padding-bottom: 4rem; /* Ajusta este valor si la barra de input cambia de altura */
        }
    </style>
</head>
<body class="h-full bg-gray-100">

    <div id="chat-container" class="h-screen flex flex-col overflow-hidden">

        <!-- Header Fijo -->
        <header class="blue-gradient text-white p-3 md:p-4 flex items-center shadow-md flex-shrink-0 z-10">
            <a href="dashboard.php" class="mr-2 md:mr-3 text-white hover:text-blue-200 transition duration-150 flex-shrink-0">
                <i class="fas fa-arrow-left fa-lg"></i>
            </a>
            <div class="relative flex-shrink-0 mr-2 md:mr-3">
                <div class="w-9 h-9 md:w-10 md:h-10 rounded-full bg-blue-300 flex items-center justify-center text-blue-800 font-bold text-sm md:text-base">
                    <span><?php echo strtoupper(substr(htmlspecialchars($other_user_name), 0, 1)); ?></span>
                </div>
                <span id="status-dot-indicator" class="status-dot absolute bottom-0 right-0 block w-3 h-3 border-2 border-white rounded-full <?php echo $other_user_status === 'online' ? 'bg-green-500' : 'bg-gray-500'; ?>"></span>
            </div>
            <div class="flex-1 min-w-0 mx-1 md:mx-2">
                <h1 class="font-semibold md:font-bold truncate text-sm md:text-base leading-tight"><?php echo htmlspecialchars($other_user_name); ?></h1>
                <p class="text-xs text-blue-100 truncate" id="status-text"><?php echo $other_user_status === 'online' ? 'Online' : 'Offline'; ?></p>
            </div>
            <div class="flex flex-shrink-0">
                <button class="p-2 text-white hover:text-blue-200 transition duration-150" id="audio-call-btn" title="Llamada de voz (no implementado)">
                    <i class="fas fa-phone"></i>
                </button>
            </div>
        </header>

        <!-- Área de Mensajes Scrollable -->
        <div class="flex-1 overflow-y-auto bg-gray-200 p-3 md:p-4" id="chat-messages">
            <!-- Mensajes renderizados por JS -->
        </div>

        <!-- Indicador "Escribiendo..." -->
        <div id="typing-indicator" class="px-3 md:px-4 py-1 bg-gray-200 text-gray-500 text-xs md:text-sm hidden flex-shrink-0 flex items-center">
            <span id="typing-user-name" class="mr-1"><?php echo htmlspecialchars($other_user_name); ?></span> está escribiendo
            <div class="typing-indicator inline-block ml-1"><span></span><span></span><span></span></div>
        </div>

        <!-- Área de Input Fija -->
        <div class="bg-gray-100 p-2 md:p-3 border-t border-gray-300 flex items-end flex-shrink-0">
            <div class="flex-1 bg-white rounded-full shadow-sm flex items-center px-2 py-1 relative mr-2">
                <div id="emoji-picker-container">
                    <!-- Emoji Mart Picker se insertará aquí -->
                </div>
                <button class="text-gray-500 p-2 hover:text-blue-500 focus:outline-none flex-shrink-0" id="emoji-btn">
                    <i class="far fa-smile fa-lg"></i>
                </button>
                <input type="text" id="message-input" placeholder="Escribe un mensaje..." class="w-full py-2 px-1 md:px-2 focus:outline-none bg-transparent text-sm md:text-base min-w-0">
                <label for="file-input" class="text-gray-500 p-2 cursor-pointer hover:text-blue-500 flex-shrink-0">
                    <i class="fas fa-paperclip fa-lg"></i>
                </label>
                <input type="file" id="file-input" class="hidden" accept="image/*,video/*,application/*,text/*">
            </div>
            <button id="send-btn" class="w-10 h-10 md:w-11 md:h-11 rounded-full blue-gradient text-white flex items-center justify-center flex-shrink-0 focus:outline-none focus:ring-2 focus:ring-offset-1 focus:ring-blue-400 disabled:opacity-50 transition duration-150">
                <i class="fas fa-paper-plane"></i>
            </button>
        </div>

    </div> <!-- Fin del #chat-container -->

    <!-- Scripts JS -->
    <script src="https://cdn.jsdelivr.net/npm/emoji-mart@latest/dist/browser.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/photoswipe/5.4.4/umd/photoswipe.umd.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/photoswipe/5.4.4/umd/photoswipe-lightbox.umd.min.js"></script>

    <script>
        // --- Variables Globales ---
        const chatContainer = document.getElementById('chat-container');
        const chatMessagesDiv = document.getElementById('chat-messages');
        const messageInput = document.getElementById('message-input');
        const sendBtn = document.getElementById('send-btn');
        const emojiBtn = document.getElementById('emoji-btn');
        const fileInput = document.getElementById('file-input');
        const typingIndicator = document.getElementById('typing-indicator');
        const statusText = document.getElementById('status-text');
        const statusDotIndicator = document.getElementById('status-dot-indicator');
        const emojiPickerContainer = document.getElementById('emoji-picker-container');
        const currentUserId = <?php echo json_encode($user_id); ?>;
        const otherUserId = <?php echo json_encode($other_user_id); ?>;
        const otherUserName = <?php echo json_encode($other_user_name); ?>;

        let lastMessageId = 0;
        let emojiPicker = null;
        let fetchInterval = null;
        let isFetching = false;
        let optimisticMessageIdCounter = 0;
        let lightboxInstance = null;
        const MAX_FILE_SIZE_MB = 50;
        const MAX_FILE_SIZE_BYTES = MAX_FILE_SIZE_MB * 1024 * 1024;

        // --- Funciones Auxiliares ---
        function renderMessage(msg, isOptimistic = false, tempId = null) {
            if (!msg || (!msg.id && !tempId)) { console.error("renderMessage: Datos inválidos", msg); return; }
            const messageId = msg.id || tempId;
            const existingElement = chatMessagesDiv.querySelector(`[data-message-id="${messageId}"]`);
            if (!isOptimistic && msg.id && tempId) { const el = chatMessagesDiv.querySelector(`[data-message-id="${tempId}"]`); if (el) el.remove(); if (chatMessagesDiv.querySelector(`[data-message-id="${msg.id}"]`)) return; } else if (existingElement) { return; }

            const messageElement = document.createElement('div');
            const isSender = msg.sender_id === currentUserId;
            messageElement.classList.add('mb-3', 'flex', isSender ? 'justify-end' : 'justify-start');
            messageElement.dataset.messageId = messageId;

            let contentHTML = '';
            const escapedMessage = msg.message ? msg.message.replace(/</g, "<").replace(/>/g, ">") : '';

            if (isOptimistic && msg.type !== 'text') {
                 contentHTML = `<div class="flex items-center p-3 rounded-lg bg-blue-600 text-white opacity-70 max-w-xs md:max-w-sm"><div class="spinner-tiny mr-3 flex-shrink-0"></div><div class="min-w-0"><div class="font-medium truncate">${msg.file_name || 'Subiendo...'}</div><div class="text-xs text-blue-200">${formatFileSize(msg.file_size) || ''}</div>${escapedMessage ? `<p class="mt-1 text-sm text-blue-100 break-words">${escapedMessage}</p>` : ''}</div></div>`;
            } else {
                switch (msg.type) {
                    case 'image': const thumbSrc = msg.file_url || msg.temp_preview_url || ''; const largeSrc = msg.file_url || ''; const canOpenLightbox = largeSrc && typeof window.PhotoSwipeLightbox !== 'undefined'; contentHTML = `<div class="max-w-xs md:max-w-sm ${canOpenLightbox ? 'cursor-pointer' : ''} message-image-container" ${canOpenLightbox ? `onclick="openPhotoSwipe(event, '${largeSrc.replace(/'/g, "\\'")}')"` : ''}><img src="${thumbSrc}" alt="${msg.file_name || 'Imagen'}" class="rounded-lg max-w-full h-auto shadow-md block">${escapedMessage ? `<p class="mt-1 text-sm ${isSender ? 'text-white opacity-90' : 'text-gray-700'} break-words">${escapedMessage}</p>` : ''}</div>`; break;
                    case 'video': contentHTML = `<div class="max-w-xs md:max-w-sm"><video controls class="rounded-lg max-w-full h-auto shadow-md block" preload="metadata"><source src="${msg.file_url}" type="${msg.file_type || 'video/mp4'}">Video no soportado. <a href="${msg.file_url}" target="_blank" class="underline ${isSender ? 'text-blue-200 hover:text-white' : 'text-blue-600 hover:text-blue-800'}">Descargar</a></video>${escapedMessage ? `<p class="mt-1 text-sm ${isSender ? 'text-white opacity-90' : 'text-gray-700'} break-words">${escapedMessage}</p>` : ''}</div>`; break;
                    case 'file': const fileSizeFormatted = formatFileSize(msg.file_size); contentHTML = `<a href="${msg.file_url}" target="_blank" download="${msg.file_name || 'archivo'}" class="flex items-center p-3 rounded-lg ${isSender ? 'bg-blue-600 text-white' : 'bg-gray-300 text-gray-800'} hover:bg-opacity-80 transition duration-150 shadow-sm max-w-xs md:max-w-sm"><i class="fas ${getFileIcon(msg.file_type || '')} fa-lg mr-3 flex-shrink-0 ${isSender ? 'text-blue-100' : 'text-gray-600'}"></i><div class="min-w-0"><div class="font-medium truncate">${msg.file_name || 'Archivo adjunto'}</div><div class="text-xs ${isSender ? 'text-blue-200' : 'text-gray-500'}">${fileSizeFormatted}</div>${escapedMessage ? `<p class="mt-1 text-sm ${isSender ? 'text-blue-100' : 'text-gray-600'} break-words">${escapedMessage}</p>` : ''}</div></a>`; break;
                    default: const urlRegex = /(\b(https?|ftp|file):\/\/[-A-Z0-9+&@#\/%?=~_|!:,.;]*[-A-Z0-9+&@#\/%=~_|])/ig; const linkedMessage = escapedMessage.replace(urlRegex, (url) => `<a href="${url}" target="_blank" rel="noopener noreferrer" class="underline ${isSender ? 'text-white hover:text-blue-200' : 'text-blue-600 hover:text-blue-800'}">${url}</a>`); contentHTML = `<p class="whitespace-pre-wrap break-words">${linkedMessage}</p>`; break;
                }
            }

            let messageDate;
            if (msg.timestamp_iso) { messageDate = new Date(msg.timestamp_iso); }
            else if (msg.timestamp) { messageDate = new Date(msg.timestamp); } // Fallback para optimista (usa ISOString)
            else { messageDate = new Date(); } // Fallback final

            let timeString = 'Hora inválida';
            if (messageDate instanceof Date && !isNaN(messageDate.getTime())) {
                try { const timeFormatter = new Intl.DateTimeFormat('es-ES', { hour: 'numeric', minute: '2-digit', hour12: false }); timeString = timeFormatter.format(messageDate); }
                catch (e) { console.error("Error formateando fecha:", e, messageDate); timeString = 'Error hora'; }
            } else {
                 console.warn("Invalid date object for message. TS info:", msg.timestamp_iso || msg.timestamp);
                 try { const timeFormatter = new Intl.DateTimeFormat('es-ES', { hour: 'numeric', minute: '2-digit', hour12: false }); timeString = timeFormatter.format(new Date()); } catch (e) { timeString = '--:--'; }
            }

            const statusIconHTML = isSender ? (isOptimistic ? `<i class="fas fa-clock ml-1 message-status-icon" title="Enviando..." style="font-size: 0.7rem; opacity: 0.6;"></i>` : renderMessageStatus(msg)) : '';
            const bubbleClasses = `p-3 rounded-lg shadow-md max-w-lg ${ isSender ? 'bg-blue-500 text-white rounded-br-none' : 'bg-white text-gray-800 rounded-bl-none' }`;

            messageElement.innerHTML = `<div class="${bubbleClasses}">${contentHTML}<div class="text-xs mt-1 ${isSender ? 'text-blue-200 opacity-90' : 'text-gray-400'} text-right flex items-center justify-end"><span>${timeString}</span>${statusIconHTML}</div></div>`;
            chatMessagesDiv.appendChild(messageElement);
        }
        function openPhotoSwipe(event, imageUrl) { event.preventDefault(); event.stopPropagation(); if (!imageUrl || typeof window.PhotoSwipeLightbox === 'undefined') { console.error("PhotoSwipe no cargado/URL inválida."); alert("Error al abrir imagen."); return; } const img = new Image(); img.onload = () => initializeAndOpenPhotoSwipe([{ src: imageUrl, w: img.naturalWidth || 1024, h: img.naturalHeight || 768 }]); img.onerror = () => { console.warn("No se pudo precargar imagen:", imageUrl); initializeAndOpenPhotoSwipe([{ src: imageUrl, w: 1024, h: 768 }]); }; img.src = imageUrl; }
        function initializeAndOpenPhotoSwipe(slideData) { if (lightboxInstance) { lightboxInstance.destroy(); lightboxInstance = null; } lightboxInstance = new PhotoSwipeLightbox({ dataSource: slideData, pswpModule: window.PhotoSwipe }); lightboxInstance.on('error', ({ error, D }) => console.error('PhotoSwipeLightbox error:', error, D)); lightboxInstance.init(); lightboxInstance.loadAndOpen(0); }
        function getFileIcon(mimeType) { if (!mimeType) return 'fa-file'; if (mimeType.startsWith('image/')) return 'fa-file-image'; if (mimeType.startsWith('video/')) return 'fa-file-video'; if (mimeType.startsWith('audio/')) return 'fa-file-audio'; if (mimeType === 'application/pdf') return 'fa-file-pdf'; if (mimeType.includes('word')) return 'fa-file-word'; if (mimeType.includes('excel') || mimeType.includes('spreadsheetml')) return 'fa-file-excel'; if (mimeType.includes('powerpoint') || mimeType.includes('presentationml')) return 'fa-file-powerpoint'; if (mimeType.includes('zip') || mimeType.includes('rar') || mimeType.includes('compressed')) return 'fa-file-archive'; if (mimeType.startsWith('text/')) return 'fa-file-alt'; return 'fa-file'; }
        function renderMessageStatus(msg) { const isRead = parseInt(msg.read || 0); const isDelivered = parseInt(msg.delivered || 0); let iconClass = 'fa-clock'; let tooltip = 'Enviado'; if (isDelivered) { iconClass = 'fa-check'; tooltip = 'Entregado'; } if (isRead) { iconClass = 'fa-check-double text-blue-400'; tooltip = 'Leído'; } return `<i class="fas ${iconClass} ml-1 message-status-icon" title="${tooltip}" style="font-size: 0.75rem; opacity: 0.8;"></i>`; }
        function formatFileSize(bytes) { if (bytes === null || bytes === undefined || isNaN(bytes)) return ''; if (bytes === 0) return '0 Bytes'; const k = 1024; const sizes = ['Bytes', 'KB', 'MB', 'GB', 'TB']; const i = Math.floor(Math.log(bytes) / Math.log(k)); const size = parseFloat((bytes / Math.pow(k, i)).toFixed(i > 0 ? 1 : 0)); return size + ' ' + sizes[i]; }
        function scrollToBottom(force = false) { const isScrolledToBottom = chatMessagesDiv.scrollHeight - chatMessagesDiv.scrollTop - chatMessagesDiv.clientHeight < 150; if (force || isScrolledToBottom) { setTimeout(() => { chatMessagesDiv.scrollTop = chatMessagesDiv.scrollHeight; }, 50); } }
        function loadInitialMessages() { let maxId = 0; const initialMessages = <?php echo json_encode($messages); ?> || []; initialMessages.forEach(msg => { renderMessage(msg); const msgId = parseInt(msg.id); if (msgId > maxId) maxId = msgId; }); lastMessageId = maxId; console.log("ID último mensaje inicial:", lastMessageId); setTimeout(() => scrollToBottom(true), 300); }
        function updateStatusUI(status) { const isOnline = status === 'online'; statusText.textContent = isOnline ? 'Online' : 'Offline'; statusDotIndicator.classList.toggle('bg-green-500', isOnline); statusDotIndicator.classList.toggle('bg-gray-500', !isOnline); }
        async function fetchNewMessages() {
            if (isFetching) return; isFetching = true;
            try {
                const url = `get_new_messages.php?other_user_id=${otherUserId}&last_message_id=${lastMessageId}`;
                const response = await fetch(url);
                if (!response.ok) { console.error('Error fetchNewMessages:', response.statusText); isFetching = false; return; }
                const data = await response.json();
                if (data.status === 'success') {
                    let newMessagesRendered = false;
                    if (data.messages && data.messages.length > 0) { data.messages.forEach(msg => { if (!chatMessagesDiv.querySelector(`[data-message-id="${msg.id}"]`)) { renderMessage(msg); newMessagesRendered = true; } }); }
                    if (data.read_by_other && data.read_by_other.length > 0) { data.read_by_other.forEach(readId => { const el = chatMessagesDiv.querySelector(`[data-message-id="${readId}"]`); if (el) { const icon = el.querySelector('.message-status-icon'); if (icon && !icon.classList.contains('fa-check-double')) { icon.className = 'fas fa-check-double text-blue-400 ml-1 message-status-icon'; icon.title = 'Leído'; icon.style.cssText = 'font-size: 0.75rem; opacity: 0.8;'; } } }); }
                    if (data.last_processed_id && parseInt(data.last_processed_id) > lastMessageId) { lastMessageId = parseInt(data.last_processed_id); }
                    if (newMessagesRendered) { scrollToBottom(); }
                    if (data.user_status && data.user_status.status) { updateStatusUI(data.user_status.status); }
                    if (typeof data.is_typing !== 'undefined') { typingIndicator.classList.toggle('hidden', !data.is_typing); if(data.is_typing) typingIndicator.querySelector('#typing-user-name').textContent = otherUserName; }
                } else if (data.message === 'No autenticado') { clearInterval(fetchInterval); alert('Sesión expirada. Inicia sesión de nuevo.'); window.location.href = 'login.php'; }
                else if (data.message === 'No new messages') { if (data.user_status && data.user_status.status) { updateStatusUI(data.user_status.status); } if (typeof data.is_typing !== 'undefined') { typingIndicator.classList.toggle('hidden', !data.is_typing); if(data.is_typing) typingIndicator.querySelector('#typing-user-name').textContent = otherUserName; } }
                else { console.warn('Respuesta fetchNewMessages:', data.message || 'Desconocida'); }
            } catch (error) { console.error('Error fatal fetchNewMessages:', error); } finally { isFetching = false; }
        }
        async function sendMessage() {
            const messageText = messageInput.value.trim(); const file = fileInput.files[0]; if (!messageText && !file) return; if (file && file.size > MAX_FILE_SIZE_BYTES) { alert(`Archivo "${file.name}" (${formatFileSize(file.size)}) excede límite de ${MAX_FILE_SIZE_MB} MB.`); fileInput.value = ''; messageInput.placeholder = "Escribe un mensaje..."; return; }
            optimisticMessageIdCounter++; const tempId = `optimistic-${optimisticMessageIdCounter}`; const optimisticMessageData = { sender_id: currentUserId, receiver_id: otherUserId, message: messageText, type: file ? (file.type.startsWith('image/') ? 'image' : (file.type.startsWith('video/') ? 'video' : 'file')) : 'text', timestamp: new Date().toISOString(), file_name: file ? file.name : null, file_size: file ? file.size : null, file_type: file ? file.type : null, delivered: 0, read: 0 };
            renderMessage(optimisticMessageData, true, tempId); scrollToBottom(true);
            const previousPlaceholder = messageInput.placeholder; messageInput.value = ''; fileInput.value = ''; messageInput.placeholder = "Escribe un mensaje...";
            const formData = new FormData(); if (typeof otherUserId !== 'number' || otherUserId <= 0) { console.error('Error sendMessage: otherUserId inválido:', otherUserId); const el = chatMessagesDiv.querySelector(`[data-message-id="${tempId}"]`); if(el) el.remove(); alert('Error: Destinatario inválido.'); return; } formData.append('receiver_id', otherUserId); if (messageText) formData.append('message', messageText); if (file) formData.append('file', file);
            sendBtn.disabled = true; messageInput.disabled = true; emojiBtn.disabled = true;
            try {
                const response = await fetch('send_message.php', { method: 'POST', body: formData }); const data = await response.json(); const optimisticElement = chatMessagesDiv.querySelector(`[data-message-id="${tempId}"]`); if (optimisticElement) optimisticElement.remove();
                if (data.status === 'success' && data.message && data.message.id) { renderMessage(data.message, false); if (parseInt(data.message.id) > lastMessageId) lastMessageId = parseInt(data.message.id); }
                else { alert(`Error al enviar: ${data.message || 'Respuesta inválida.'}`); console.error("Error send_message.php:", data); if(messageText) messageInput.value = messageText; if(file) messageInput.placeholder = previousPlaceholder; }
            } catch (error) { console.error('Error de red al enviar:', error); alert('Error de conexión al enviar. Inténtalo de nuevo.'); const el = chatMessagesDiv.querySelector(`[data-message-id="${tempId}"]`); if (el) el.remove(); if(messageText) messageInput.value = messageText; if(file) messageInput.placeholder = previousPlaceholder; }
            finally { sendBtn.disabled = false; messageInput.disabled = false; emojiBtn.disabled = false; messageInput.focus(); }
        }
        // --- Inicialización y Event Listeners ---
        document.addEventListener('DOMContentLoaded', () => {
             if (typeof window.EmojiMart === 'undefined') { console.error("EmojiMart no cargado!"); emojiBtn.style.display = 'none'; }
             if (typeof window.PhotoSwipeLightbox === 'undefined' || typeof window.PhotoSwipe === 'undefined') { console.error("PhotoSwipe no cargado!"); }
             if (typeof otherUserId !== 'number' || otherUserId <= 0) { console.error("FATAL: otherUserId inválido:", otherUserId); alert("Error cargando chat."); messageInput.disabled = true; sendBtn.disabled = true; emojiBtn.disabled = true; messageInput.placeholder = "Error"; return; }
             loadInitialMessages(); fetchInterval = setInterval(fetchNewMessages, 3000); setTimeout(() => { messageInput.focus(); }, 150);
             sendBtn.addEventListener('click', sendMessage); messageInput.addEventListener('keypress', (e) => { if (e.key === 'Enter' && !e.shiftKey) { e.preventDefault(); sendMessage(); } });
             emojiBtn.addEventListener('click', (event) => { if (typeof window.EmojiMart === 'undefined' || typeof window.EmojiMart.Picker === 'undefined') { console.error("EmojiMart no listo."); return; } event.stopPropagation(); if (emojiPickerContainer.style.display === 'block') { emojiPickerContainer.style.display = 'none'; } else { if (!emojiPicker) { try { emojiPicker = new EmojiMart.Picker({ onEmojiSelect: (emoji) => { const start = messageInput.selectionStart; const end = messageInput.selectionEnd; messageInput.value = messageInput.value.substring(0, start) + emoji.native + messageInput.value.substring(end); messageInput.selectionStart = messageInput.selectionEnd = start + emoji.native.length; messageInput.focus(); if (emojiPickerContainer) emojiPickerContainer.style.display = 'none'; }, locale: 'es', theme: 'light', set: 'native', previewPosition: 'none', searchPosition: 'none', navPosition: 'bottom', perLine: 8 }); emojiPickerContainer.innerHTML = ''; emojiPickerContainer.appendChild(emojiPicker); } catch (e) { console.error("Error EmojiMart Picker:", e); alert("Error al cargar emojis."); return; } } emojiPickerContainer.style.display = 'block'; } });
             document.addEventListener('click', (event) => { if (emojiPickerContainer.style.display === 'block' && !emojiPickerContainer.contains(event.target) && event.target !== emojiBtn && !emojiBtn.contains(event.target)) { emojiPickerContainer.style.display = 'none'; } });
             fileInput.addEventListener('change', (event) => { const file = event.target.files[0]; if (file) { if (file.size > MAX_FILE_SIZE_BYTES) { alert(`Archivo muy grande (${formatFileSize(file.size)}). Límite ${MAX_FILE_SIZE_MB} MB.`); fileInput.value = ''; messageInput.placeholder = "Escribe un mensaje..."; } else { messageInput.placeholder = `Archivo: ${file.name}`; } } else { messageInput.placeholder = "Escribe un mensaje..."; } });
             document.addEventListener('keydown', (e) => { if (e.key === 'Escape' && window.lightboxInstance && window.lightboxInstance.pswp && window.lightboxInstance.pswp.isOpen) { window.lightboxInstance.close(); } });
             document.getElementById('audio-call-btn')?.addEventListener('click', () => { console.log('Iniciar llamada (no implementado)'); alert('Llamada de voz no disponible.'); });
        });
    </script>
</body>
</html>